summaryrefslogtreecommitdiff
path: root/src/mongo/db/exec/sort_test.cpp
diff options
context:
space:
mode:
authorJason Rassi <rassi@10gen.com>2015-01-09 11:23:15 -0500
committerJason Rassi <rassi@10gen.com>2015-01-12 12:40:45 -0500
commit2468153c690dbe8312a10829d3cd7565ed90c1e1 (patch)
tree5f4bd3d5326face3d7f6a30b48dae5fbcd0253e2 /src/mongo/db/exec/sort_test.cpp
parentae7a1a999b9352948cb49dfaf80a4ad3c7eabd5d (diff)
downloadmongo-2468153c690dbe8312a10829d3cd7565ed90c1e1.tar.gz
SERVER-16659 Rename MockStage to QueuedDataStage
It is no longer the case that this stage is only used for testing.
Diffstat (limited to 'src/mongo/db/exec/sort_test.cpp')
-rw-r--r--src/mongo/db/exec/sort_test.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/mongo/db/exec/sort_test.cpp b/src/mongo/db/exec/sort_test.cpp
index c890fb4dd15..3f627346f11 100644
--- a/src/mongo/db/exec/sort_test.cpp
+++ b/src/mongo/db/exec/sort_test.cpp
@@ -32,8 +32,8 @@
#include "mongo/db/exec/sort.h"
+#include "mongo/db/exec/queued_data_stage.h"
#include "mongo/db/json.h"
-#include "mongo/db/exec/mock_stage.h"
#include "mongo/unittest/unittest.h"
using namespace mongo;
@@ -44,8 +44,8 @@ namespace {
TEST(SortStageTest, SortEmptyWorkingSet) {
WorkingSet ws;
- // MockStage will be owned by SortStage.
- MockStage* ms = new MockStage(&ws);
+ // QueuedDataStage will be owned by SortStage.
+ QueuedDataStage* ms = new QueuedDataStage(&ws);
SortStageParams params;
SortStage sort(params, &ws, ms);
@@ -84,8 +84,8 @@ namespace {
// so it's fine to declare
WorkingSet ws;
- // MockStage will be owned by SortStage.
- MockStage* ms = new MockStage(&ws);
+ // QueuedDataStage will be owned by SortStage.
+ QueuedDataStage* ms = new QueuedDataStage(&ws);
BSONObj inputObj = fromjson(inputStr);
BSONElement inputElt = inputObj.getField("input");
ASSERT(inputElt.isABSONObj());